Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/il0373_simpletest.py
    :caption: examples/il0373_simpletest.py
    :linenos:

Device Specific Examples
------------------------

.. literalinclude:: ../examples/il0373_1.54_color.py
    :caption: examples/il0373_1.54_color.py
    :linenos:

.. literalinclude:: ../examples/il0373_2.9_color.py
    :caption: examples/il0373_2.9_color.py
    :linenos:

.. literalinclude:: ../examples/il0373_2.9_grayscale.py
    :caption: examples/il0373_2.9_grayscale.py
    :linenos:

.. literalinclude:: ../examples/il0373_2.13_color.py
    :caption: examples/il0373_2.13_color.py
    :linenos:

.. literalinclude:: ../examples/il0373_flexible_2.9_monochrome.py
    :caption: examples/il0373_flexible_2.9_monochrome.py
    :linenos:

.. literalinclude:: ../examples/il0373_flexible_2.13_monochrome.py
    :caption: examples/il0373_2.13_monochrome.py
    :linenos:
